@@ -12,6 +12,7 @@ from loglan_db.model_db.base_connect_tables import t_connect_keys
 from loglan_db.model_db.base_definition import BaseDefinition
 from loglan_db.model_db.base_event import BaseEvent
 from loglan_db.model_db.base_key import BaseKey
+from loglan_db.model_db.base_word import BaseWord
 from loglan_db.model_db.base_word import db
 
 
@@ -24,12 +25,14 @@ class AddonWordGetter:
     event_end_id: db.Column = None
 
     @classmethod
-    def by_event(cls, event_id: Union[BaseEvent, int] = None) -> BaseQuery:
+    def by_event(
+            cls, event_id: Union[BaseEvent, int] = None,
+            add_to: BaseQuery = None) -> BaseQuery:
         """Query filtered by specified Event (latest by default)
 
         Args:
           event_id: Union[BaseEvent, int]: Event object or Event.id (int) (Default value = None)
-
+          add_to:
         Returns:
           BaseQuery
 
@@ -39,64 +42,59 @@ class AddonWordGetter:
 
         event_id = BaseEvent.id if isinstance(event_id, BaseEvent) else int(event_id)
 
-        return cls.query.filter(cls.event_start_id <= event_id) \
-            .filter(or_(cls.event_end_id > event_id, cls.event_end_id.is_(None))) \
-            .order_by(cls.name)
+        request = add_to if add_to else cls.query
+        return cls._filter_event(event_id, request).order_by(cls.name)
+
+    @staticmethod
+    def _filter_event(event_id: Union[BaseEvent, int], add_to: BaseQuery) -> BaseQuery:
+        return add_to.filter(BaseWord.event_start_id <= event_id) \
+            .filter(or_(BaseWord.event_end_id > event_id, BaseWord.event_end_id.is_(None)))
 
     @classmethod
-    def by_name(cls, name: str, case_sensitive: bool = False) -> BaseQuery:
+    def by_name(cls, name: str, event_id: Union[BaseEvent, int] = None, case_sensitive: bool = False,
+                add_to: BaseQuery = None) -> BaseQuery:
         """Word.Query filtered by specified name
 
         Args:
+          event_id:
           name: str:
           case_sensitive: bool:  (Default value = False)
-
+          add_to:
         Returns:
           BaseQuery
 
         """
-        if case_sensitive:
-            return cls.query.filter(cls.name == name)
-        return cls.query.filter(cls.name.in_([name, name.lower(), name.upper()]))
+
+        request = add_to if add_to else cls.query
+        name = name.replace("*", "%")
+        return cls.by_event(event_id, request).filter(
+            BaseWord.name.like(name) if not case_sensitive else BaseWord.name.ilike(name)
+        )
 
     @classmethod
-    def by_key(
-            cls, key: Union[BaseKey, str],
-            language: str = None,
-            case_sensitive: bool = False,
-            partial_results: bool = False) -> BaseQuery:
+    def by_key(cls, key: Union[BaseKey, str], language: str = None, event_id: Union[BaseEvent, int] = None,
+               case_sensitive: bool = False, add_to: BaseQuery = None) -> BaseQuery:
         """Word.Query filtered by specified key
 
         Args:
           key: Union[BaseKey, str]:
           language: str: Language of key (Default value = None)
+          event_id: Union[BaseEvent, int]:  (Default value = None)
           case_sensitive: bool:  (Default value = False)
-          partial_results: bool:
+          add_to:
         Returns:
           BaseQuery
 
         """
 
-        key = BaseKey.word if isinstance(key, BaseKey) else str(key)
-        request = cls.query.join(BaseDefinition, t_connect_keys, BaseKey)
+        request = add_to if add_to else cls.query
+        request = cls.by_event(event_id, request)
 
-        if case_sensitive:
-            request = cls.__case_sensitive_filter(key, request, partial_results)
-        request = cls.__case_insensitive_filter(key, request, partial_results)
+        key = (BaseKey.word if isinstance(key, BaseKey) else str(key)).replace("*", "%")
+        request = request.join(BaseDefinition, t_connect_keys, BaseKey).filter(
+            BaseKey.word.like(key) if case_sensitive else BaseKey.word.ilike(key))
 
         if language:
             request = request.filter(BaseKey.language == language)
 
         return request.order_by(cls.name)
-
-    @staticmethod
-    def __case_sensitive_filter(
-            key: str, request: BaseQuery, partial_results: bool) -> BaseQuery:
-        return request.filter(BaseKey.word.like(f"{key}%")) \
-            if partial_results else request.filter(BaseKey.word == key)
-
-    @staticmethod
-    def __case_insensitive_filter(
-            key: str, request: BaseQuery, partial_results: bool) -> BaseQuery:
-        return request.filter(BaseKey.word.ilike(f"{key}%")) \
-            if partial_results else request.filter(BaseKey.word.ilike(key))
