@@ -8,8 +8,6 @@ from itertools import groupby
 from typing import Union, Optional, List, Dict
 from dataclasses import dataclass
 
-from sqlalchemy import or_
-from flask_sqlalchemy import BaseQuery
 from loglan_db.model_db.addons.addon_word_getter import AddonWordGetter
 from loglan_db.model_db.base_event import BaseEvent
 from loglan_db.model_db.base_word import BaseWord
@@ -35,8 +33,7 @@ class AddonWordTranslator:
     def definitions_by_key(
             key: str, words: List[BaseWord],
             style: str = DEFAULT_HTML_STYLE,
-            case_sensitive: bool = False,
-            partial_results: bool = False) -> dict:
+            case_sensitive: bool = False) -> dict:
         """
 
         Args:
@@ -44,22 +41,19 @@ class AddonWordTranslator:
             words:
             style:
             case_sensitive:
-            partial_results:
         Returns:
 
         """
 
         def conditions(
                 x_key: str, x_keys: list,
-                x_case_sensitive: bool,
-                x_partial_results: bool) -> bool:
+                x_case_sensitive: bool) -> bool:
             current_keys = [k.word for k in x_keys] if \
                 x_case_sensitive else [k.word.lower() for k in x_keys]
             current_key = x_key if x_case_sensitive else x_key.lower()
 
-            if x_partial_results:
-                return any([k.startswith(current_key) for k in current_keys])
-            return current_key in current_keys
+            import fnmatch
+            return bool([n for n in current_keys if fnmatch.fnmatchcase(n, current_key)])
 
         result: Dict[str, List[str]] = {}
         for word in words:
@@ -67,38 +61,35 @@ class AddonWordTranslator:
             definitions = [
                 HTMLExportDefinition.export_for_english(d, word=key, style=style)
                 for d in word.definitions if conditions(
-                    key, d.keys, case_sensitive, partial_results
-                )]
+                    key, d.keys, case_sensitive)]
             result[word.name].extend(definitions)
         return result
 
     @staticmethod
-    def translation_by_key(
-            key: str, language: str = None,
-            style: str = DEFAULT_HTML_STYLE,
-            case_sensitive: bool = False,
-            partial_results: bool = False) -> Optional[str]:
+    def translation_by_key(key: str, language: str = None, style: str = DEFAULT_HTML_STYLE,
+                           event_id: Union[BaseEvent, int, str] = None, case_sensitive: bool = False) -> Optional[str]:
         """
         Get information about loglan words by key in a foreign language
         Args:
             key:
             language:
             style:
+            event_id:
             case_sensitive:
-            partial_results:
         Returns:
 
         """
 
         words = HTMLExportWord.by_key(
-            key, language, case_sensitive, partial_results
-        ).order_by(HTMLExportWord.name).all()
-
+            key=key, language=language, event_id=event_id,
+            case_sensitive=case_sensitive).all()
+        print([w.name for w in words])
         if not words:
             return None
 
         result = HTMLExportWord.definitions_by_key(
-            key, words, style, case_sensitive, partial_results)
+            key=key, words=words, style=style,
+            case_sensitive=case_sensitive)
 
         new = '\n'
 
@@ -106,7 +97,9 @@ class AddonWordTranslator:
                          for _, definitions in result.items()]).strip()
 
 
-class HTMLExportWord(BaseWord, AddonWordGetter, AddonWordTranslator, AddonExportWordConverter):
+class HTMLExportWord(
+    BaseWord, AddonWordGetter,
+    AddonWordTranslator, AddonExportWordConverter):
     """
     HTMLExportWord Class
     """
@@ -115,8 +108,7 @@ class HTMLExportWord(BaseWord, AddonWordGetter, AddonWordTranslator, AddonExport
     def html_all_by_name(
             cls, name: str, style: str = DEFAULT_HTML_STYLE,
             event_id: Union[BaseEvent, int, str] = None,
-            case_sensitive: bool = False,
-            partial_results: bool = False) -> Optional[str]:
+            case_sensitive: bool = False) -> Optional[str]:
         """
         Convert all words found by name into one HTML string
         Args:
@@ -124,7 +116,6 @@ class HTMLExportWord(BaseWord, AddonWordGetter, AddonWordTranslator, AddonExport
             style: HTML design style
             event_id:
             case_sensitive:
-            partial_results:
         Returns:
 
         """
@@ -139,7 +130,10 @@ class HTMLExportWord(BaseWord, AddonWordGetter, AddonWordTranslator, AddonExport
 
         event_id = int(event_id) if isinstance(event_id, (int, str)) else BaseEvent.id
 
-        words = cls.get_words_by(name, event_id, case_sensitive, partial_results)
+        words = cls.by_name(
+            name=name, event_id=event_id,
+            case_sensitive=case_sensitive
+        ).all()
 
         if not words:
             return None
@@ -148,42 +142,6 @@ class HTMLExportWord(BaseWord, AddonWordGetter, AddonWordTranslator, AddonExport
 
         return words_template[style] % "\n".join(items)
 
-    @classmethod
-    def get_words_by(
-            cls, name: str, event_id: int,
-            case_sensitive: bool, partial_results: bool) -> List[HTMLExportWord]:
-        """
-        Args:
-            name:
-            event_id:
-            case_sensitive:
-            partial_results:
-
-        Returns:
-
-        """
-        words = cls.query.filter(cls.event_start_id <= event_id) \
-            .filter(or_(cls.event_end_id > event_id, cls.event_end_id.is_(None)))
-        if case_sensitive:
-            words = cls.__case_sensitive_words_filter(name, words, partial_results)
-        else:
-            words = cls.__case_insensitive_words_filter(name, words, partial_results)
-        return words.order_by(cls.name).all()
-
-    # TOD0 Merge all filter code to onw place
-
-    @classmethod
-    def __case_sensitive_words_filter(
-            cls, key: str, request: BaseQuery, partial_results: bool) -> BaseQuery:
-        return request.filter(cls.name.like(f"{key}%")) \
-            if partial_results else request.filter(cls.name == key)
-
-    @classmethod
-    def __case_insensitive_words_filter(
-            cls, key: str, request: BaseQuery, partial_results: bool) -> BaseQuery:
-        return request.filter(cls.name.ilike(f"{key}%")) \
-            if partial_results else request.filter(cls.name.ilike(key))
-
     @staticmethod
     def _get_stylized_words(
             words: list, style: str = DEFAULT_HTML_STYLE) -> List[str]:
@@ -298,8 +256,8 @@ class HTMLExportWord(BaseWord, AddonWordGetter, AddonWordTranslator, AddonExport
                   self.e_usedin.replace("| ", "|&nbsp;"), self.e_year, None]
         default_values = [str(), str(), str(), str(), str(), None, str(), tags[style][-1]]
 
-        return tuple([_tagger(tag, value, default_value) for tag, value, default_value in
-                      zip(tags[style], values, default_values)])
+        return tuple(_tagger(tag, value, default_value) for tag, value, default_value
+                     in zip(tags[style], values, default_values))
 
     def html_meaning(self, style: str = DEFAULT_HTML_STYLE) -> str:
         """
